@@ -17,11 +17,11 @@
 
 from http.server import HTTPServer, BaseHTTPRequestHandler
 from jinja2 import __version__ as jinja2_version
-import jinjafx, os, io, sys, socket, signal, threading, yaml, json, base64, time, datetime
+import jinjafx, os, io, sys, socket, signal, threading, yaml, json, base64, time, datetime, resource
 import re, argparse, zipfile, hashlib, traceback, glob, hmac, uuid, struct, binascii, gzip, requests
 import cmarkgfm, emoji, func_timeout
 
-__version__ = '22.8.0'
+__version__ = '22.8.1'
 
 lock = threading.RLock()
 base = os.path.abspath(os.path.dirname(__file__))
@@ -327,11 +327,11 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
                 y = yaml.load(gyaml, Loader=yaml.SafeLoader)
                 if y != None:
                   gvars.update(y)
-  
+
               try:
                 st = round(time.time() * 1000)
                 ocount = 0
-      
+
                 if timelimit > 0:
                   outputs = func_timeout.func_timeout(timelimit, jinjafx.JinjaFx().jinjafx, args=(template.decode('utf-8'), data.decode('utf-8'), gvars, 'Output', [], True))
                 else:
@@ -339,7 +339,7 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
                             
               except func_timeout.FunctionTimedOut:
                 raise Exception("execution time limit of " + str(timelimit) + "s exceeded")
-  
+
               jsr = {
                 'status': 'ok',
                 'elapsed': round(time.time() * 1000) - st,
@@ -710,6 +710,7 @@ def main(rflag=[0]):
     group_ex.add_argument('-s3', metavar='<aws s3 url>', type=str)
     parser.add_argument('-rl', metavar='<rate/limit>', type=rlimit)
     parser.add_argument('-tl', metavar='<time limit>', type=int, default=0)
+    parser.add_argument('-ml', metavar='<memory limit>', type=int, default=0)
     parser.add_argument('-v', action='store_true', default=False)
     args = parser.parse_args()
     verbose = args.v
@@ -744,6 +745,10 @@ def main(rflag=[0]):
     signal.signal(signal.SIGINT, signal_handler)
     signal.signal(signal.SIGTERM, signal_handler)
 
+    if args.ml:
+      soft, hard = resource.getrlimit(resource.RLIMIT_AS)
+      resource.setrlimit(resource.RLIMIT_AS, (args.ml * 1024 * 1024, hard))
+
     log('Starting JinjaFx Server (PID is ' + str(os.getpid()) + ') on http://' + args.l + ':' + str(args.p) + '...')
 
     s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
@@ -755,7 +760,7 @@ def main(rflag=[0]):
     threads = []
     repository = args.r
 
-    for i in range(64):
+    for i in range(16):
       threads.append(JinjaFxThread(s, (args.l, args.p)))
 
     while rflag[0] < 2:
